#!/bin/bash

if [ -f '/usr/sbin/wildix_shell_tools' ]; then
	. /usr/sbin/wildix_shell_tools
else
	logger -t "${0}" "ERROR: can't include wildix_shell_tools"
	exit 1
fi

CORES="$1" ; RAM="$2" ; AMAZON="$3" ; DOCKER="$4"

if [ -z $CORES ] || [ -z $RAM ] || [ -z $AMAZON ] || [ -z $DOCKER ]; then
	log "ERROR: zero values (exit)" "${0##*/}"
	exit 0
fi


SF2='/rw2/etc/sf2'
E_CONF='/rw2/etc/ejabberd/resources_vars.yml'
E_MAM_CONF='/rw2/etc/ejabberd/ejabberd_mod_mam.yml'


# get parameters
[ -s "$E_MAM_CONF" ] && GET_SQL_BACKEND="$(awk -F ':|: ' '/sql_type:/{print $2}' $E_MAM_CONF)"


# calculation max values
if [ "$RAM" -le "2048" ]; then

	E_MAX_FSM_QUEUE=1000
	E_MAX_LUA_WORKERS=10
	E_CACHE_SIZE=2000
	E_SQL_POOL_SIZE=4

elif [ "$RAM" -gt "2048" ] && [ "$RAM" -le "4096" ]; then

	E_MAX_FSM_QUEUE=2000
	E_MAX_LUA_WORKERS=20
	E_CACHE_SIZE=4000
	E_SQL_POOL_SIZE=8	

elif [ "$RAM" -gt "4096" ] && [ "$RAM" -le "8192" ]; then

	E_MAX_FSM_QUEUE=4000
	E_MAX_LUA_WORKERS=40
	E_CACHE_SIZE=8000
	E_SQL_POOL_SIZE=16

elif [ "$RAM" -gt "8192" ]; then

	E_MAX_FSM_QUEUE=10000
	E_MAX_LUA_WORKERS=40
	E_CACHE_SIZE=20000
	E_SQL_POOL_SIZE=20

fi


# limit max values
[ "$GET_SQL_BACKEND" == "sqlite" ] && E_SQL_POOL_SIZE=1


# set values to config
if [ -s "$E_CONF" ]; then
	sed -i "s/max_fsm_queue:.*/max_fsm_queue: $E_MAX_FSM_QUEUE/g" $E_CONF
	sed -i "s/sql_pool_size:.*/sql_pool_size: $E_SQL_POOL_SIZE/g" $E_CONF
	sed -i "s/cache_size:.*/cache_size: $E_CACHE_SIZE/g" $E_CONF
	sed -i "s/max_lua_workers:.*/max_lua_workers: $E_MAX_LUA_WORKERS/g" $E_CONF
fi
